weaviate.data package
=====================

.. automodule:: weaviate.data
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   weaviate.data.references
   weaviate.data.replication

Submodules
----------

weaviate.data.crud\_data module
-------------------------------

.. automodule:: weaviate.data.crud_data
   :members:
   :undoc-members:
   :show-inheritance:
